@@ -23,8 +23,7 @@ import picocli.CommandLine;
 import picocli.CommandLine.Command;
 
 @Command(name = "map", description = "Map commands.",
-    subcommands = {Init.class, Export.class, Serve.class, Dev.class, StyleCommand.class,
-        MBTiles.class},
+    subcommands = {Init.class, Export.class, Serve.class, Dev.class, MBTiles.class},
     sortOptions = false)
 public class Map implements Runnable {
 
