@@ -17,17 +17,52 @@
 
 package org.apache.baremaps.workflow.tasks;
 
+import java.util.StringJoiner;
 import org.apache.baremaps.workflow.Task;
 import org.apache.baremaps.workflow.WorkflowContext;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-public record LogMessage(String message) implements Task {
+/**
+ * Log a message.
+ */
+public class LogMessage implements Task {
 
   private static final Logger logger = LoggerFactory.getLogger(LogMessage.class);
 
+  private String message;
+
+  /**
+   * Constructs a {@code LogMessage}.
+   */
+  public LogMessage() {
+
+  }
+
+  /**
+   * Constructs an {@code LogMessage}.
+   *
+   * @param message the message
+   */
+  public LogMessage(String message) {
+    this.message = message;
+  }
+
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public void execute(WorkflowContext context) throws Exception {
     logger.info(message);
   }
+
+  /**
+   * {@inheritDoc}
+   */
+  @Override
+  public String toString() {
+    return new StringJoiner(", ", LogMessage.class.getSimpleName() + "[", "]")
+        .add("message='" + message + "'")
+        .toString();
+  }
 }
