@@ -17,31 +17,24 @@
 
 package org.apache.baremaps.server;
 
+import com.linecorp.armeria.server.annotation.Get;
+import com.linecorp.armeria.server.annotation.ProducesJson;
 import java.util.function.Supplier;
-import javax.inject.Inject;
-import javax.inject.Singleton;
-import javax.ws.rs.GET;
-import javax.ws.rs.Produces;
-import javax.ws.rs.core.MediaType;
 import org.apache.baremaps.vectortile.tilejson.TileJSON;
 
 /**
  * A resource that provides access to the tileJSON file.
  */
-@Singleton
-@javax.ws.rs.Path("/")
 public class TileJSONResource {
 
   private final Supplier<TileJSON> tileJSONSupplier;
 
-  @Inject
   public TileJSONResource(Supplier<TileJSON> tileJSONSupplier) {
     this.tileJSONSupplier = tileJSONSupplier;
   }
 
-  @GET
-  @javax.ws.rs.Path("tiles.json")
-  @Produces(MediaType.APPLICATION_JSON)
+  @Get("/tiles.json")
+  @ProducesJson
   public TileJSON getTileset() {
     return tileJSONSupplier.get();
   }
